@@ -48,6 +48,7 @@ from defusedxml import ElementTree as SafeElementTree  # type:ignore[import-unty
 
 from .formatters import BaseNameFormatter, CurrentFormatter
 from .helpers import BaseHelper
+from .xml import xs_normalizedString, xs_token
 
 # `Intersection` is still not implemented, so it is interim replaced by Union for any support
 # see section "Intersection" in https://peps.python.org/pep-0483/
@@ -59,7 +60,7 @@ import typing  # noqa: F401 # isort: skip
 
 # !! version is managed by semantic_release
 # do not use typing here, or else `semantic_release` might have issues finding the variable
-__version__ = '1.0.2'
+__version__ = '1.1.1'
 
 _logger = getLogger(__name__)
 _logger.addHandler(NullHandler())
@@ -128,6 +129,47 @@ class XmlArraySerializationType(Enum):
     NESTED = 2
 
 
+@unique
+class XmlStringSerializationType(Enum):
+    """
+    Enum to differentiate how string-type properties are serialized.
+    """
+    STRING = 1
+    """
+    as raw string.
+    see https://www.w3.org/TR/xmlschema-2/#string
+    """
+    NORMALIZED_STRING = 2
+    """
+    as `normalizedString`.
+    see http://www.w3.org/TR/xmlschema-2/#normalizedString"""
+    TOKEN = 3
+    """
+    as `token`.
+    see http://www.w3.org/TR/xmlschema-2/#token"""
+
+    # unimplemented cases
+    # - https://www.w3.org/TR/xmlschema-2/#language
+    # - https://www.w3.org/TR/xmlschema-2/#NMTOKEN
+    # - https://www.w3.org/TR/xmlschema-2/#Name
+
+
+# region _xs_string_mod_apply
+
+__XS_STRING_MODS: Dict[XmlStringSerializationType, Callable[[str], str]] = {
+    XmlStringSerializationType.NORMALIZED_STRING: xs_normalizedString,
+    XmlStringSerializationType.TOKEN: xs_token,
+}
+
+
+def _xs_string_mod_apply(v: str, t: Optional[XmlStringSerializationType]) -> str:
+    mod = __XS_STRING_MODS.get(t)  # type: ignore[arg-type]
+    return mod(v) if mod else v
+
+
+# endregion _xs_string_mod_apply
+
+
 def _allow_property_for_view(prop_info: 'ObjectMetadataLibrary.SerializableProperty', value_: Any,
                              view_: Optional[Type[ViewType]]) -> bool:
     # First check Property is part of the View is given
@@ -200,8 +242,8 @@ class _SerializableJsonEncoder(JSONEncoder):
 
                 new_key = BaseNameFormatter.decode_handle_python_builtins_and_keywords(name=k)
 
-                if prop_info.custom_names.get(SerializationType.JSON, None):
-                    new_key = str(prop_info.custom_names.get(SerializationType.JSON))
+                if custom_name := prop_info.custom_names.get(SerializationType.JSON):
+                    new_key = str(custom_name)
 
                 if CurrentFormatter.formatter:
                     new_key = CurrentFormatter.formatter.encode(property_name=new_key)
@@ -264,7 +306,7 @@ class _JsonSerializable(Protocol):
         """
         _logger.debug('Rendering JSON to %s...', cls)
         klass_qualified_name = f'{cls.__module__}.{cls.__qualname__}'
-        klass = ObjectMetadataLibrary.klass_mappings.get(klass_qualified_name, None)
+        klass = ObjectMetadataLibrary.klass_mappings.get(klass_qualified_name)
         klass_properties = ObjectMetadataLibrary.klass_property_mappings.get(klass_qualified_name, {})
 
         if klass is None:
@@ -275,9 +317,8 @@ class _JsonSerializable(Protocol):
 
         if len(klass_properties) == 1:
             k, only_prop = next(iter(klass_properties.items()))
-            if only_prop.custom_names.get(SerializationType.JSON, None) == '.':
-                _data = {only_prop.name: data}
-                return cls(**_data)
+            if only_prop.custom_names.get(SerializationType.JSON) == '.':
+                return cls(**{only_prop.name: data})
 
         _data = copy(data)
         for k, v in data.items():
@@ -289,8 +330,9 @@ class _JsonSerializable(Protocol):
 
             new_key = None
             if decoded_k not in klass_properties:
+                _allowed_custom_names = {decoded_k, k}
                 for p, pi in klass_properties.items():
-                    if pi.custom_names.get(SerializationType.JSON, None) in [decoded_k, k]:
+                    if pi.custom_names.get(SerializationType.JSON) in _allowed_custom_names:
                         new_key = p
             else:
                 new_key = decoded_k
@@ -306,7 +348,7 @@ class _JsonSerializable(Protocol):
             _data[new_key] = v
 
         for k, v in _data.items():
-            prop_info = klass_properties.get(k, None)
+            prop_info = klass_properties.get(k)
             if not prop_info:
                 raise ValueError(f'No Prop Info for {k} in {cls}')
 
@@ -349,6 +391,9 @@ class _JsonSerializable(Protocol):
         return cls(**_data)
 
 
+_XML_BOOL_REPRESENTATIONS_TRUE = ('1', 'true')
+
+
 class _XmlSerializable(Protocol):
 
     def as_xml(self: Any, view_: Optional[Type[ViewType]] = None,
@@ -391,7 +436,13 @@ class _XmlSerializable(Protocol):
                     elif prop_info.is_enum:
                         v = v.value
 
-                    this_e_attributes.update({_namespace_element_name(new_key, xmlns): str(v)})
+                    if v is None:
+                        v = prop_info.get_none_value_for_view(view_=view_)
+                    if v is None:
+                        continue
+
+                    this_e_attributes[_namespace_element_name(new_key, xmlns)] = \
+                        _xs_string_mod_apply(str(v), prop_info.xml_string_config)
 
         element_name = _namespace_element_name(
             element_name if element_name else CurrentFormatter.formatter.encode(self.__class__.__name__),
@@ -407,9 +458,6 @@ class _XmlSerializable(Protocol):
                 # Skip as rendering for a view and this Property is not registered form this View
                 continue
 
-            if v is None:
-                v = prop_info.get_none_value_for_view(view_=view_)
-
             new_key = BaseNameFormatter.decode_handle_python_builtins_and_keywords(name=k)
 
             if not prop_info:
@@ -418,12 +466,15 @@ class _XmlSerializable(Protocol):
             if not prop_info.is_xml_attribute:
                 new_key = prop_info.custom_names.get(SerializationType.XML, new_key)
 
+                if v is None:
+                    v = prop_info.get_none_value_for_view(view_=view_)
                 if v is None:
                     SubElement(this_e, _namespace_element_name(tag_name=new_key, xmlns=xmlns))
                     continue
 
                 if new_key == '.':
-                    this_e.text = str(v)
+                    this_e.text = _xs_string_mod_apply(str(v),
+                                                       prop_info.xml_string_config)
                     continue
 
                 if CurrentFormatter.formatter:
@@ -442,14 +493,16 @@ class _XmlSerializable(Protocol):
                             nested_e.append(
                                 j.as_xml(view_=view_, as_string=False, element_name=nested_key, xmlns=xmlns))
                         elif prop_info.is_enum:
-                            SubElement(nested_e, nested_key).text = str(j.value)
+                            SubElement(nested_e, nested_key).text = _xs_string_mod_apply(str(j.value),
+                                                                                         prop_info.xml_string_config)
                         elif prop_info.concrete_type in (float, int):
                             SubElement(nested_e, nested_key).text = str(j)
                         elif prop_info.concrete_type is bool:
                             SubElement(nested_e, nested_key).text = str(j).lower()
                         else:
                             # Assume type is str
-                            SubElement(nested_e, nested_key).text = str(j)
+                            SubElement(nested_e, nested_key).text = _xs_string_mod_apply(str(j),
+                                                                                         prop_info.xml_string_config)
                 elif prop_info.custom_type:
                     if prop_info.is_helper_type():
                         v_ser = prop_info.custom_type.xml_normalize(
@@ -459,11 +512,14 @@ class _XmlSerializable(Protocol):
                         elif isinstance(v_ser, Element):
                             this_e.append(v_ser)
                         else:
-                            SubElement(this_e, new_key).text = str(v_ser)
+                            SubElement(this_e, new_key).text = _xs_string_mod_apply(str(v_ser),
+                                                                                    prop_info.xml_string_config)
                     else:
-                        SubElement(this_e, new_key).text = str(prop_info.custom_type(v))
+                        SubElement(this_e, new_key).text = _xs_string_mod_apply(str(prop_info.custom_type(v)),
+                                                                                prop_info.xml_string_config)
                 elif prop_info.is_enum:
-                    SubElement(this_e, new_key).text = str(v.value)
+                    SubElement(this_e, new_key).text = _xs_string_mod_apply(str(v.value),
+                                                                            prop_info.xml_string_config)
                 elif not prop_info.is_primitive_type():
                     global_klass_name = f'{prop_info.concrete_type.__module__}.{prop_info.concrete_type.__name__}'
                     if global_klass_name in ObjectMetadataLibrary.klass_mappings:
@@ -472,16 +528,19 @@ class _XmlSerializable(Protocol):
                     else:
                         # Handle properties that have a type that is not a Python Primitive (e.g. int, float, str)
                         if prop_info.string_format:
-                            SubElement(this_e, new_key).text = f'{v:{prop_info.string_format}}'
+                            SubElement(this_e, new_key).text = _xs_string_mod_apply(f'{v:{prop_info.string_format}}',
+                                                                                    prop_info.xml_string_config)
                         else:
-                            SubElement(this_e, new_key).text = str(v)
+                            SubElement(this_e, new_key).text = _xs_string_mod_apply(str(v),
+                                                                                    prop_info.xml_string_config)
                 elif prop_info.concrete_type in (float, int):
                     SubElement(this_e, new_key).text = str(v)
                 elif prop_info.concrete_type is bool:
                     SubElement(this_e, new_key).text = str(v).lower()
                 else:
                     # Assume type is str
-                    SubElement(this_e, new_key).text = str(v)
+                    SubElement(this_e, new_key).text = _xs_string_mod_apply(str(v),
+                                                                            prop_info.xml_string_config)
 
         if as_string:
             return cast(Element, SafeElementTree.tostring(this_e, 'unicode'))
@@ -496,7 +555,7 @@ class _XmlSerializable(Protocol):
         ``serializable``.
         """
         _logger.debug('Rendering XML from %s to %s...', type(data), cls)
-        klass = ObjectMetadataLibrary.klass_mappings.get(f'{cls.__module__}.{cls.__qualname__}', None)
+        klass = ObjectMetadataLibrary.klass_mappings.get(f'{cls.__module__}.{cls.__qualname__}')
         if klass is None:
             _logger.warning('%s.%s is not a known serializable class', cls.__module__, cls.__qualname__,
                             stacklevel=2)
@@ -508,9 +567,9 @@ class _XmlSerializable(Protocol):
             data = cast(Element, SafeElementTree.fromstring(data.read()))
 
         if default_namespace is None:
-            _namespaces = dict([node for _, node in
-                                SafeElementTree.iterparse(StringIO(SafeElementTree.tostring(data, 'unicode')),
-                                                          events=['start-ns'])])
+            _namespaces = dict(node for _, node in
+                               SafeElementTree.iterparse(StringIO(SafeElementTree.tostring(data, 'unicode')),
+                                                         events=['start-ns']))
             default_namespace = (re_compile(r'^\{(.*?)\}.').search(data.tag) or (None, _namespaces.get('')))[1]
 
         if default_namespace is None:
@@ -531,14 +590,17 @@ class _XmlSerializable(Protocol):
 
             if decoded_k not in klass_properties:
                 for p, pi in klass_properties.items():
-                    if pi.custom_names.get(SerializationType.XML, None) == decoded_k:
+                    if pi.custom_names.get(SerializationType.XML) == decoded_k:
                         decoded_k = p
 
-            prop_info = klass_properties.get(decoded_k, None)
+            prop_info = klass_properties.get(decoded_k)
             if not prop_info:
                 raise ValueError(f'Non-primitive types not supported from XML Attributes - see {decoded_k} for '
                                  f'{cls.__module__}.{cls.__qualname__} which has Prop Metadata: {prop_info}')
 
+            if prop_info.xml_string_config:
+                v = _xs_string_mod_apply(v, prop_info.xml_string_config)
+
             if prop_info.custom_type and prop_info.is_helper_type():
                 _data[decoded_k] = prop_info.custom_type.xml_deserialize(v)
             elif prop_info.is_enum:
@@ -551,12 +613,20 @@ class _XmlSerializable(Protocol):
         # Handle Node text content
         if data.text:
             for p, pi in klass_properties.items():
-                if pi.custom_names.get(SerializationType.XML, None) == '.':
-                    _data[p] = data.text.strip()
+                if pi.custom_names.get(SerializationType.XML) == '.':
+                    _data[p] = _xs_string_mod_apply(data.text.strip(), pi.xml_string_config)
 
         # Handle Sub-Elements
         for child_e in data:
             decoded_k = CurrentFormatter.formatter.decode(strip_default_namespace(child_e.tag))
+
+            if decoded_k not in klass_properties:
+                for p, pi in klass_properties.items():
+                    if pi.xml_array_config:
+                        array_type, nested_name = pi.xml_array_config
+                        if nested_name == strip_default_namespace(child_e.tag):
+                            decoded_k = p
+
             if decoded_k in klass.ignore_during_deserialization:
                 _logger.debug('Ignoring %s when deserializing %s.%s', decoded_k, cls.__module__, cls.__qualname__)
                 continue
@@ -570,19 +640,22 @@ class _XmlSerializable(Protocol):
                                 decoded_k = p
                             else:
                                 decoded_k = '____SKIP_ME____'
-                    elif pi.custom_names.get(SerializationType.XML, None) == decoded_k:
+                    elif pi.custom_names.get(SerializationType.XML) == decoded_k:
                         decoded_k = p
 
             if decoded_k == '____SKIP_ME____':
                 continue
 
-            prop_info = klass_properties.get(decoded_k, None)
+            prop_info = klass_properties.get(decoded_k)
             if not prop_info:
                 raise ValueError(f'{decoded_k} is not a known Property for {cls.__module__}.{cls.__qualname__}')
 
             try:
                 _logger.debug('Handling %s', prop_info)
 
+                if child_e.text:
+                    child_e.text = _xs_string_mod_apply(child_e.text, prop_info.xml_string_config)
+
                 if prop_info.is_array and prop_info.xml_array_config:
                     array_type, nested_name = prop_info.xml_array_config
 
@@ -591,6 +664,9 @@ class _XmlSerializable(Protocol):
 
                     if array_type == XmlArraySerializationType.NESTED:
                         for sub_child_e in child_e:
+                            if sub_child_e.text:
+                                sub_child_e.text = _xs_string_mod_apply(sub_child_e.text,
+                                                                        prop_info.xml_string_config)
                             if not prop_info.is_primitive_type() and not prop_info.is_enum:
                                 _data[decoded_k].append(prop_info.concrete_type.from_xml(
                                     data=sub_child_e, default_namespace=default_namespace)
@@ -628,7 +704,7 @@ class _XmlSerializable(Protocol):
                         _data[decoded_k] = prop_info.concrete_type(child_e.text)
                 else:
                     if prop_info.concrete_type == bool:
-                        _data[decoded_k] = True if str(child_e.text) in (1, 'true') else False
+                        _data[decoded_k] = str(child_e.text) in _XML_BOOL_REPRESENTATIONS_TRUE
                     else:
                         _data[decoded_k] = prop_info.concrete_type(child_e.text)
             except AttributeError as e:
@@ -636,9 +712,8 @@ class _XmlSerializable(Protocol):
                                   'The Property is: %s\n'
                                   'The Value was: %s\n',
                                   cls, prop_info, v)
-                raise AttributeError(
-                    f'There was an AttributeError deserializing XML to {cls} the Property {prop_info}: {e}'
-                ) from e
+                raise AttributeError('There was an AttributeError deserializing XML '
+                                     f'to {cls} the Property {prop_info}: {e}') from e
 
         _logger.debug('Creating %s from %s', cls, _data)
 
@@ -665,6 +740,7 @@ class ObjectMetadataLibrary:
     _deferred_property_type_parsing: Dict[str, Set['ObjectMetadataLibrary.SerializableProperty']] = {}
     _klass_views: Dict[str, Type[ViewType]] = {}
     _klass_property_array_config: Dict[str, Tuple[XmlArraySerializationType, str]] = {}
+    _klass_property_string_config: Dict[str, Optional[XmlStringSerializationType]] = {}
     _klass_property_attributes: Set[str] = set()
     _klass_property_include_none: Dict[str, Set[Tuple[Type[ViewType], Any]]] = {}
     _klass_property_names: Dict[str, Dict[SerializationType, str]] = {}
@@ -691,7 +767,7 @@ class ObjectMetadataLibrary:
             if serialization_types is None:
                 serialization_types = _DEFAULT_SERIALIZATION_TYPES
             self._serialization_types = serialization_types
-            self._ignore_during_deserialization = set(ignore_during_deserialization or [])
+            self._ignore_during_deserialization = set(ignore_during_deserialization or ())
 
         @property
         def name(self) -> str:
@@ -723,16 +799,19 @@ class ObjectMetadataLibrary:
         """
 
         _ARRAY_TYPES = {'List': List, 'Set': Set, 'SortedSet': Set}
-        _DEFAULT_XML_SEQUENCE = 100
         _SORTED_CONTAINERS_TYPES = {'SortedList': List, 'SortedSet': Set}
         _PRIMITIVE_TYPES = (bool, int, float, str)
 
-        def __init__(self, *, prop_name: str, prop_type: Any, custom_names: Dict[SerializationType, str],
+        _DEFAULT_XML_SEQUENCE = 100
+
+        def __init__(self, *,
+                     prop_name: str, prop_type: Any, custom_names: Dict[SerializationType, str],
                      custom_type: Optional[Any] = None,
                      include_none_config: Optional[Set[Tuple[Type[ViewType], Any]]] = None,
                      is_xml_attribute: bool = False, string_format_: Optional[str] = None,
                      views: Optional[Iterable[Type[ViewType]]] = None,
                      xml_array_config: Optional[Tuple[XmlArraySerializationType, str]] = None,
+                     xml_string_config: Optional[XmlStringSerializationType] = None,
                      xml_sequence_: Optional[int] = None) -> None:
 
             self._name = prop_name
@@ -751,8 +830,9 @@ class ObjectMetadataLibrary:
                 self._include_none_views = set()
             self._is_xml_attribute = is_xml_attribute
             self._string_format = string_format_
-            self._views = set(views or [])
+            self._views = set(views or ())
             self._xml_array_config = xml_array_config
+            self._xml_string_config = xml_string_config
             self._xml_sequence = xml_sequence_ or self._DEFAULT_XML_SEQUENCE
 
             self._deferred_type_parsing = False
@@ -767,7 +847,7 @@ class ObjectMetadataLibrary:
             return self._custom_names
 
         def custom_name(self, serialization_type: SerializationType) -> Optional[str]:
-            return self.custom_names.get(serialization_type, None)
+            return self.custom_names.get(serialization_type)
 
         @property
         def type_(self) -> Any:
@@ -823,6 +903,10 @@ class ObjectMetadataLibrary:
         def is_array(self) -> bool:
             return self._is_array
 
+        @property
+        def xml_string_config(self) -> Optional[XmlStringSerializationType]:
+            return self._xml_string_config
+
         @property
         def is_enum(self) -> bool:
             return self._is_enum
@@ -865,7 +949,7 @@ class ObjectMetadataLibrary:
                 match = re_search(r"^(?P<array_type>[\w.]+)\[['\"]?(?P<array_of>\w+)['\"]?]$", type_to_parse)
                 if match:
                     results = match.groupdict()
-                    if results.get('array_type', None) in self._SORTED_CONTAINERS_TYPES:
+                    if results.get('array_type') in self._SORTED_CONTAINERS_TYPES:
                         mapped_array_type = self._SORTED_CONTAINERS_TYPES.get(str(results.get('array_type')))
                         self._is_array = True
                         try:
@@ -991,7 +1075,7 @@ class ObjectMetadataLibrary:
                                     klasses: Iterable[str]) -> None:
         for _k in klasses:
             if _k not in ObjectMetadataLibrary._deferred_property_type_parsing:
-                ObjectMetadataLibrary._deferred_property_type_parsing.update({_k: set([])})
+                ObjectMetadataLibrary._deferred_property_type_parsing[_k] = set()
             ObjectMetadataLibrary._deferred_property_type_parsing[_k].add(prop)
 
     @classmethod
@@ -1017,42 +1101,33 @@ class ObjectMetadataLibrary:
         if cls.is_klass_serializable(klass=klass):
             return klass
 
-        cls.klass_mappings.update({
-            f'{klass.__module__}.{klass.__qualname__}': ObjectMetadataLibrary.SerializableClass(
-                klass=klass, serialization_types=serialization_types,
-                ignore_during_deserialization=ignore_during_deserialization
-            )
-        })
+        cls.klass_mappings[f'{klass.__module__}.{klass.__qualname__}'] = ObjectMetadataLibrary.SerializableClass(
+            klass=klass, serialization_types=serialization_types,
+            ignore_during_deserialization=ignore_during_deserialization
+        )
 
         qualified_class_name = f'{klass.__module__}.{klass.__qualname__}'
-        cls.klass_property_mappings.update({qualified_class_name: {}})
+        cls.klass_property_mappings[qualified_class_name] = {}
         _logger.debug('Registering Class %s with custom name %s', qualified_class_name, custom_name)
         for name, o in getmembers(klass, ObjectMetadataLibrary.is_property):
             qualified_property_name = f'{qualified_class_name}.{name}'
             prop_arg_specs = getfullargspec(o.fget)
 
-            cls.klass_property_mappings[qualified_class_name].update({
-                name: ObjectMetadataLibrary.SerializableProperty(
-                    prop_name=name,
-                    custom_names=ObjectMetadataLibrary._klass_property_names.get(qualified_property_name, {}),
-                    prop_type=prop_arg_specs.annotations.get('return', None),
-                    custom_type=ObjectMetadataLibrary._klass_property_types.get(qualified_property_name, None),
-                    include_none_config=ObjectMetadataLibrary._klass_property_include_none.get(
-                        qualified_property_name, None
-                    ),
-                    is_xml_attribute=(qualified_property_name in ObjectMetadataLibrary._klass_property_attributes),
-                    string_format_=ObjectMetadataLibrary._klass_property_string_formats.get(
-                        qualified_property_name, None
-                    ),
-                    views=ObjectMetadataLibrary._klass_property_views.get(
-                        qualified_property_name, None
-                    ),
-                    xml_array_config=ObjectMetadataLibrary._klass_property_array_config.get(
-                        qualified_property_name, None
-                    ),
-                    xml_sequence_=ObjectMetadataLibrary._klass_property_xml_sequence.get(qualified_property_name, 100)
-                )
-            })
+            cls.klass_property_mappings[qualified_class_name][name] = ObjectMetadataLibrary.SerializableProperty(
+                prop_name=name,
+                custom_names=ObjectMetadataLibrary._klass_property_names.get(qualified_property_name, {}),
+                prop_type=prop_arg_specs.annotations.get('return'),
+                custom_type=ObjectMetadataLibrary._klass_property_types.get(qualified_property_name),
+                include_none_config=ObjectMetadataLibrary._klass_property_include_none.get(qualified_property_name),
+                is_xml_attribute=(qualified_property_name in ObjectMetadataLibrary._klass_property_attributes),
+                string_format_=ObjectMetadataLibrary._klass_property_string_formats.get(qualified_property_name),
+                views=ObjectMetadataLibrary._klass_property_views.get(qualified_property_name),
+                xml_array_config=ObjectMetadataLibrary._klass_property_array_config.get(qualified_property_name),
+                xml_string_config=ObjectMetadataLibrary._klass_property_string_config.get(qualified_property_name),
+                xml_sequence_=ObjectMetadataLibrary._klass_property_xml_sequence.get(
+                    qualified_property_name,
+                    ObjectMetadataLibrary.SerializableProperty._DEFAULT_XML_SEQUENCE)
+            )
 
         if SerializationType.JSON in serialization_types:
             klass.as_json = _JsonSerializable.as_json  # type:ignore[attr-defined]
@@ -1063,58 +1138,63 @@ class ObjectMetadataLibrary:
             klass.from_xml = classmethod(_XmlSerializable.from_xml.__func__)  # type:ignore[attr-defined]
 
         # Handle any deferred Properties depending on this class
-        if klass.__qualname__ in ObjectMetadataLibrary._deferred_property_type_parsing:
-            for _p in ObjectMetadataLibrary._deferred_property_type_parsing.get(klass.__qualname__, {}):
-                _p.parse_type_deferred()
+        for _p in ObjectMetadataLibrary._deferred_property_type_parsing.get(klass.__qualname__, ()):
+            _p.parse_type_deferred()
 
         return klass
 
     @classmethod
     def register_custom_json_property_name(cls, qual_name: str, json_property_name: str) -> None:
-        if qual_name in cls._klass_property_names:
-            cls._klass_property_names.get(qual_name, {}).update({SerializationType.JSON: json_property_name})
+        prop = cls._klass_property_names.get(qual_name)
+        if prop is None:
+            cls._klass_property_names[qual_name] = {SerializationType.JSON: json_property_name}
         else:
-            cls._klass_property_names.update({qual_name: {SerializationType.JSON: json_property_name}})
+            prop[SerializationType.JSON] = json_property_name
 
     @classmethod
     def register_custom_string_format(cls, qual_name: str, string_format: str) -> None:
-        cls._klass_property_string_formats.update({qual_name: string_format})
+        cls._klass_property_string_formats[qual_name] = string_format
 
     @classmethod
     def register_custom_xml_property_name(cls, qual_name: str, xml_property_name: str) -> None:
-        if qual_name in cls._klass_property_names:
-            cls._klass_property_names[qual_name].update({SerializationType.XML: xml_property_name})
+        prop = cls._klass_property_names.get(qual_name)
+        if prop:
+            prop[SerializationType.XML] = xml_property_name
         else:
-            cls._klass_property_names.update({qual_name: {SerializationType.XML: xml_property_name}})
+            cls._klass_property_names[qual_name] = {SerializationType.XML: xml_property_name}
 
     @classmethod
     def register_klass_view(cls, klass: Type[_T], view_: Type[ViewType]) -> Type[_T]:
-        ObjectMetadataLibrary._klass_views.update({
-            f'{klass.__module__}.{klass.__qualname__}': view_
-        })
+        ObjectMetadataLibrary._klass_views[f'{klass.__module__}.{klass.__qualname__}'] = view_
         return klass
 
     @classmethod
     def register_property_include_none(cls, qual_name: str, view_: Optional[Type[ViewType]] = None,
                                        none_value: Optional[Any] = None) -> None:
-        if qual_name not in cls._klass_property_include_none:
-            cls._klass_property_include_none.update({qual_name: set()})
-        if view_:
-            cls._klass_property_include_none.get(qual_name, set()).add((view_, none_value))
+        prop = cls._klass_property_include_none.get(qual_name)
+        val = (view_ or ViewType, none_value)
+        if prop is None:
+            cls._klass_property_include_none[qual_name] = {val}
         else:
-            cls._klass_property_include_none.get(qual_name, set()).add((ViewType, none_value))
+            prop.add(val)
 
     @classmethod
     def register_property_view(cls, qual_name: str, view_: Type[ViewType]) -> None:
-        if qual_name not in ObjectMetadataLibrary._klass_property_views:
-            ObjectMetadataLibrary._klass_property_views.update({qual_name: {view_}})
+        prop = ObjectMetadataLibrary._klass_property_views.get(qual_name)
+        if prop is None:
+            ObjectMetadataLibrary._klass_property_views[qual_name] = {view_}
         else:
-            ObjectMetadataLibrary._klass_property_views.get(qual_name, set()).add(view_)
+            prop.add(view_)
 
     @classmethod
     def register_xml_property_array_config(cls, qual_name: str,
                                            array_type: XmlArraySerializationType, child_name: str) -> None:
-        cls._klass_property_array_config.update({qual_name: (array_type, child_name)})
+        cls._klass_property_array_config[qual_name] = (array_type, child_name)
+
+    @classmethod
+    def register_xml_property_string_config(cls, qual_name: str,
+                                            string_type: Optional[XmlStringSerializationType]) -> None:
+        cls._klass_property_string_config[qual_name] = string_type
 
     @classmethod
     def register_xml_property_attribute(cls, qual_name: str) -> None:
@@ -1122,11 +1202,11 @@ class ObjectMetadataLibrary:
 
     @classmethod
     def register_xml_property_sequence(cls, qual_name: str, sequence: int) -> None:
-        cls._klass_property_xml_sequence.update({qual_name: sequence})
+        cls._klass_property_xml_sequence[qual_name] = sequence
 
     @classmethod
     def register_property_type_mapping(cls, qual_name: str, mapped_type: type) -> None:
-        cls._klass_property_types.update({qual_name: mapped_type})
+        cls._klass_property_types[qual_name] = mapped_type
 
 
 @overload
@@ -1160,29 +1240,29 @@ def serializable_enum(cls: Optional[Type[_E]] = None) -> Union[
 
 @overload
 def serializable_class(
-        cls: Literal[None] = None, *,
-        name: Optional[str] = ...,
-        serialization_types: Optional[Iterable[SerializationType]] = ...,
-        ignore_during_deserialization: Optional[Iterable[str]] = ...
+    cls: Literal[None] = None, *,
+    name: Optional[str] = ...,
+    serialization_types: Optional[Iterable[SerializationType]] = ...,
+    ignore_during_deserialization: Optional[Iterable[str]] = ...
 ) -> Callable[[Type[_T]], Intersection[Type[_T], Type[_JsonSerializable], Type[_XmlSerializable]]]:
     ...
 
 
 @overload
 def serializable_class(  # type:ignore[misc] # mypy on py37
-        cls: Type[_T], *,
-        name: Optional[str] = ...,
-        serialization_types: Optional[Iterable[SerializationType]] = ...,
-        ignore_during_deserialization: Optional[Iterable[str]] = ...
+    cls: Type[_T], *,
+    name: Optional[str] = ...,
+    serialization_types: Optional[Iterable[SerializationType]] = ...,
+    ignore_during_deserialization: Optional[Iterable[str]] = ...
 ) -> Intersection[Type[_T], Type[_JsonSerializable], Type[_XmlSerializable]]:
     ...
 
 
 def serializable_class(
-        cls: Optional[Type[_T]] = None, *,
-        name: Optional[str] = None,
-        serialization_types: Optional[Iterable[SerializationType]] = None,
-        ignore_during_deserialization: Optional[Iterable[str]] = None
+    cls: Optional[Type[_T]] = None, *,
+    name: Optional[str] = None,
+    serialization_types: Optional[Iterable[SerializationType]] = None,
+    ignore_during_deserialization: Optional[Iterable[str]] = None
 ) -> Union[
     Callable[[Type[_T]], Intersection[Type[_T], Type[_JsonSerializable], Type[_XmlSerializable]]],
     Intersection[Type[_T], Type[_JsonSerializable], Type[_XmlSerializable]]
@@ -1304,6 +1384,19 @@ def xml_array(array_type: XmlArraySerializationType, child_name: str) -> Callabl
     return decorate
 
 
+def xml_string(string_type: XmlStringSerializationType) -> Callable[[_F], _F]:
+    """Decorator"""
+
+    def decorate(f: _F) -> _F:
+        _logger.debug('Registering %s.%s as XML StringType: %s', f.__module__, f.__qualname__, string_type)
+        ObjectMetadataLibrary.register_xml_property_string_config(
+            qual_name=f'{f.__module__}.{f.__qualname__}', string_type=string_type
+        )
+        return f
+
+    return decorate
+
+
 def xml_name(name: str) -> Callable[[_F], _F]:
     """Decorator"""
 
